|
| Minimal Human68K startup code by Lydux.
|
| Communication between the kernel and program is done
| by setting cpu registers as is :
| a0 : MCB pointer
| a1 : End of bss segment
| a2 : Command line pointer
| a3 : Environ variable pointer
| a4 : Execution entry point address
| a5 : Interrupt routine command number (driver only)


| This startup script will also initialize the stack and heap for you.
| 32KB are common values. You can safelly change them as your need.

__STACK_SIZE	= 32*1024
__HEAP_SIZE		= 32*1024

.extern main

.global _start

_start:
	move.l	%a0@(0x30), %a5		| .data section end = .bss start
	move.l	%a1, %d0			| a1 = .bss end
	sub.l	%a5, %d0

clear_bss:
	clr.l	%a5@+
	dbra	%d0, clear_bss

| Save some importants value provided by Human68k
	move.l	%a0, _MCB		| MCB
	lea.l	%a0@(0x100), %a5
	move.l	%a5, _PSTA		| TEXT Start
	move.l	%a0@(0x34), %d0
	move.l	%d0, _PEND		| TEXT End
	move.l	%d0, _DSTA		| DATA Start
	move.l	%a0@(0x30), %d0
	move.l	%d0, _DEND		| DATA End
	move.l	%d0, _BSTA		| BSS Start
	move.l	%a1, _BEND		| BSS End

	lea.l	%a0@(0x10), %a5
	move.l	%a5, _PSP

| Save environment
	move.l	%a3, _ENV0

| Save command line
	move.l	%a2, _cmdline

| Setup stack
	move.l	%a1, _SSTA
	add.l	#__STACK_SIZE, %a1
	move.l	%a1, _SEND

	move.l	%a1, %sp
	
| Setup heap
	move.l	%a1, _HSTA		| HEAP Start
	add.l	#__HEAP_SIZE, %a1
	move.l	%a1, _HEND		| HEAP End
	move.l	%a0@(0x08), _HMAX	| End block

	lea.l	%a0@(0x10), %a5		| PSP

	sub.l	%a5, %a1
	move.l	%a1, %sp@-		| incr
	move.l	%a5, %sp@-		| ptr
	.short	0xFF4A			| dos_setblock
	addq.l	#8, %sp

	jsr	main				| jump to user code

	move.w	%d0, %sp@-		| return code
	.short 0xff4c			| dos_exit2

|
| Variables
|
	.even

	.comm	_MCB, 4
	.comm	_PSP, 4

	.comm	_PSTA, 4
	.comm	_PEND, 4
	.comm	_DSTA, 4
	.comm	_DEND, 4
	.comm	_BSTA, 4
	.comm	_BEND, 4
	.comm	_SSTA, 4
	.comm	_SEND, 4
	.comm	_HSTA, 4
	.comm	_HEND, 4
	.comm	_HMAX, 4

	.comm	_ENV0, 4

	.comm	_cmdline, 4

